==> estateplat-common-1.1.0-20160727.070838-132-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡房屋所有权
 */
@Table(name = "GD_LS_FWSYQ")
public class GdLsFwsyq implements Serializable {
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @description 主键
	 */
    @Id
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房产证号
     */
    private String fczh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
	private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记原因
     */
	private String djyy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目主键
     */
	private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 附记
     */
    private String fj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 更新日期
     */
	private Date gxrq;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证书类型
     */
	private String zslx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 创建人ID
     */
	private String cjrid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 原权证号
     */
	private String yqzh;

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getZslx() {
		return zslx;
	}

	public void setZslx(String zslx) {
		this.zslx = zslx;
	}

	public String getCjrid() {
		return cjrid;
	}

	public void setCjrid(String cjrid) {
		this.cjrid = cjrid;
	}

	public String getYqzh() {
		return yqzh;
	}

	public void setYqzh(String yqzh) {
		this.yqzh = yqzh;
	}

	public String getQlid() {
		return qlid;
	}

	public void setQlid(String qlid) {
		this.qlid = qlid;
	}

	public String getFczh() {
		return fczh;
	}

	public void setFczh(String fczh) {
		this.fczh = fczh;
	}

	public String getDjlx() {
		return djlx;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}



}

==> estateplat-common-1.2.4-20210527.081430-778-sources.jar: cn/gtmap/estateplat/model/server/core/GdLsFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/5/27
 * @description 历史过渡房屋所有权
 */
@Table(name = "GD_LS_FWSYQ")
public class GdLsFwsyq implements Serializable {
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @description 主键
	 */
    @Id
    private String qlid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 房产证号
     */
    private String fczh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记类型
     */
	private String djlx;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 登记原因
     */
	private String djyy;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 项目主键
     */
	private String proid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 附记
     */
    private String fj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @description 证书类型
     */
	private String zslx;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/7/31
	 * @description 登簿人
	 */
	private String dbr;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/7/31
	 * @description 登记时间
	 */
	private Date djsj;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/7/31
	 * @description 档案业务号
	 */
	private String daywh;

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getZslx() {
		return zslx;
	}

	public void setZslx(String zslx) {
		this.zslx = zslx;
	}

	public String getQlid() {
		return qlid;
	}

	public void setQlid(String qlid) {
		this.qlid = qlid;
	}

	public String getFczh() {
		return fczh;
	}

	public void setFczh(String fczh) {
		this.fczh = fczh;
	}

	public String getDjlx() {
		return djlx;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public String getDbr() {
		return dbr;
	}

	public void setDbr(String dbr) {
		this.dbr = dbr;
	}

	public Date getDjsj() {
		return djsj;
	}

	public void setDjsj(Date djsj) {
		this.djsj = djsj;
	}

	public String getDaywh() {
		return daywh;
	}

	public void setDaywh(String daywh) {
		this.daywh = daywh;
	}
}
